Supported sensors
=================

**PolSARtools** currently supports the import of sensor data from the following sources into polarimetric matrices.

.. toctree::
    :maxdepth: 3

    sensors/uavsar
    sensors/isro_asar
    sensors/esar
    sensors/nisar
    sensors/risat
    sensors/radarsat2
    sensors/alos2
    sensors/chandrayaan2
    


.. - `UAVSAR (GRD, MLC) <sensors/uavsar.html>`_
.. - `NISAR (RSLC, GSLC) <sensors/nisar.html>`_
.. - `RADARSAT-2 (Full-pol) <sensors/radarsat2.html>`_
.. - `ALOS-2 (Fine Beam Dual-pol (FBD) Level 1.1 CEOS) <sensors/alos2.html>`_
.. - `Chandrayaan-II DFSAR (Full-pol) <sensors/chandrayaan2.html>`_


.. .. toctree::
..     :maxdepth: 2
..     :caption: UAVSAR (GRD, MLC)

..     sensors/uavsar

.. .. toctree::
..     :maxdepth: 2
..     :caption: NISAR (RSLC, GSLC)

..     sensors/nisar


.. .. toctree::
..     :maxdepth: 2
..     :caption: RADARSAT-2 (Full-pol)

..     sensors/radarsat2


.. .. toctree::
..     :maxdepth: 2
..     :caption: ALOS-2 (Fine Beam Dual-pol (FBD) Level 1.1 CEOS)

..     sensors/alos2

.. .. toctree::
..     :maxdepth: 2
..     :caption: Chandrayaan-II DFSAR (Full-pol)

..     sensors/chandrayaan2


